// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	common "LAPP_LF_MOM_BACKEND/models/base"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"LAPP_LF_MOM_BACKEND/utils"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterOneArtDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArtDemandLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtDemandLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterIDOfArtDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		demandId := ctx.Params().GetString("demandId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, demandId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterInsertOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandLst) error) {

	RegisterOneArtDemandLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterDeleteOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, string, int) error) {

	RegisterIDOfArtDemandLst(party, "DELETE", path+"/{demandId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterSelectOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, string, int) (*model.ArtDemandLst, error)) {

	party.Get(path+"/{demandId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		demandId := ctx.Params().GetString("demandId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, demandId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterUpdateOneArtDemandLst(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandLst) error) {

	RegisterOneArtDemandLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterMultiArtDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtDemandLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterInsertArtDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	RegisterMultiArtDemandLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterDeleteArtDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	RegisterMultiArtDemandLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterSelectArtDemandLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtDemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func RegisterUpdateArtDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLst) error) {

	RegisterMultiArtDemandLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterExportArtDemandLstList
 *-----------------------------------------------------------------------------
 *
 * @Description              : 导出供应商需求明细报表
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterExportArtDemandLstList(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterReceiveArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 供应商需求明细接收
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterReceiveArtDemandLst(party router.Party, path string, method func(*models.Usertab, []model.ArtDemandLstStatusChange, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var records model.ArtDemandLstStatusChangeRecords
		if err := ctx.ReadJSON(&records); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, records.Records, "receive")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterConfirmArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 供应商需求明细确认
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterConfirmArtDemandLst(party router.Party, path string, method func(*models.Usertab, []model.ArtDemandLstStatusChange, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var records model.ArtDemandLstStatusChangeRecords
		if err := ctx.ReadJSON(&records); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, records.Records, "confirm")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterAccomplishArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 供应商需求明细完成
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterAccomplishArtDemandLst(party router.Party, path string, method func(*models.Usertab, []model.ArtDemandLstStatusChange, string) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var records model.ArtDemandLstStatusChangeRecords
		if err := ctx.ReadJSON(&records); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		err := method(user, records.Records, "accomplish")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterSyncHronousData
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理多条RegisterUploadMustPic的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSyncHronousData(party router.Party, httpMethod string, path string, method func(int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		plant := ctx.FormValue("plantNr")
		plantNr := utils.ValueToInt(plant,0)
		if utils.ValueIsEmpty(plantNr){
			plantNr = common.PlantNr
		}
		var err error = nil
		//获取通过iris.WithPostMaxMemory获取的最大上传值大小。
		maxSize := ctx.Application().ConfigurationReadOnly().GetPostMaxMemory()
		err = ctx.Request().ParseMultipartForm(maxSize)
		if err != nil {
			ctx.StatusCode(iris.StatusInternalServerError)
			ctx.WriteString(err.Error())
			return
		}

		file, info, err := ctx.FormFile("file")
		if err != nil {
			ctx.StatusCode(iris.StatusInternalServerError)
			ctx.HTML("Error while uploading: <b>" + err.Error() + "</b>")
			return
		}
		defer file.Close()
		if info.Size > maxSize {
			ctx.StatusCode(iris.StatusRequestEntityTooLarge)
			return
		}
		guid := utils.MakeOrderSn("Sync")
		savePath := "web/public/uploadxlsx/" + guid + ".xlsx"

		// 上传文件至指定目录
		err = utils.SaveUploadedFile(info, savePath)
		if err != nil {
			return
		}

		err = method(plantNr, savePath)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), "fail")
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, "success")
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSyncHronousData
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterInsertSyncHronousData(party router.Party, path string, method func(int, string) error) {

	RegisterSyncHronousData(party, "POST", path, method)
}