// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	svr "LAPP_LF_MOM_BACKEND/services/log"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块log路由分组
	grmi.RegisterRouteMapping("/log", func(party router.Party) {

		// ArtDemandHead的路由组
		artdemandhead := party.Party("/artdemandhead")
		// ArtDemandHead的服务实例
		var serviceOfArtDemandHead = svr.NewArtDemandHeadService()
		// ArtDemandHead插入一条
		//RegisterInsertOneArtDemandHead(artdemandhead, "/insertone", serviceOfArtDemandHead.InsertOne)
		// ArtDemandHead插入多条
		//RegisterInsertArtDemandHead(artdemandhead, "/insert", serviceOfArtDemandHead.Insert)
		// ArtDemandHead删除一条
		//RegisterDeleteOneArtDemandHead(artdemandhead, "/deleteone", serviceOfArtDemandHead.DeleteOne)
		// ArtDemandHead删除多条
		//RegisterDeleteArtDemandHead(artdemandhead, "/delete", serviceOfArtDemandHead.Delete)
		// ArtDemandHead查询多条
		RegisterSelectArtDemandHead(artdemandhead, "/query", serviceOfArtDemandHead.Select)
		// ArtDemandHead列表页
		RegisterSelectArtDemandHead(artdemandhead, "/list", serviceOfArtDemandHead.Select)
		// ArtDemandHead查询一条
		RegisterSelectOneArtDemandHead(artdemandhead, "/get", serviceOfArtDemandHead.SelectOne)
		// ArtDemandHead修改一条
		//RegisterUpdateOneArtDemandHead(artdemandhead, "/updateone", serviceOfArtDemandHead.UpdateOne)
		// ArtDemandHead修改多条
		//RegisterUpdateArtDemandHead(artdemandhead, "/update", serviceOfArtDemandHead.Update)
		// 导出供应商需求批次报表
		RegisterExportArtDemandLstList(artdemandhead, "/exportexcel", serviceOfArtDemandHead.ExportExcel)
		// 供应商需求批次接收
		RegisterReceiveArtDemandHead(artdemandhead, "/receive", serviceOfArtDemandHead.ChangeArtDemandHeadStatus)
		// 供应商需求批次确认
		RegisterConfirmArtDemandHead(artdemandhead, "/confirm", serviceOfArtDemandHead.ChangeArtDemandHeadStatus)
		// 供应商需求批次完成
		RegisterAccomplishArtDemandHead(artdemandhead, "/accomplish", serviceOfArtDemandHead.ChangeArtDemandHeadStatus)
		//获取最后的时间戳
		RegisterSelectLastModify(artdemandhead, "/selectlastmodify", serviceOfArtDemandHead.SelectLastModify)

		// ArtDemandLst的路由组
		artdemandlst := party.Party("/artdemandlst")
		// ArtDemandLst的服务实例
		var serviceOfArtDemandLst = svr.NewArtDemandLstService()
		// ArtDemandLst插入一条
		RegisterInsertOneArtDemandLst(artdemandlst, "/insertone", serviceOfArtDemandLst.InsertOne)
		// ArtDemandLst插入多条
		//RegisterInsertArtDemandLst(artdemandlst, "/insert", serviceOfArtDemandLst.Insert)
		// ArtDemandLst删除一条
		RegisterDeleteOneArtDemandLst(artdemandlst, "/deleteone", serviceOfArtDemandLst.DeleteOne)
		// ArtDemandLst删除多条
		RegisterDeleteArtDemandLst(artdemandlst, "/delete", serviceOfArtDemandLst.Delete)
		// ArtDemandLst查询多条
		RegisterSelectArtDemandLst(artdemandlst, "/query", serviceOfArtDemandLst.Select)
		// ArtDemandLst列表页
		RegisterSelectArtDemandLst(artdemandlst, "/list", serviceOfArtDemandLst.Select)
		// ArtDemandLst查询一条
		RegisterSelectOneArtDemandLst(artdemandlst, "/get", serviceOfArtDemandLst.SelectOne)
		// ArtDemandLst修改一条
		RegisterUpdateOneArtDemandLst(artdemandlst, "/updateone", serviceOfArtDemandLst.UpdateOne)
		// ArtDemandLst修改多条
		// RegisterUpdateArtDemandLst(artdemandlst, "/update", serviceOfArtDemandLst.Update)
		// 导出供应商需求明细报表
		RegisterExportArtDemandLstList(artdemandlst, "/exportexcel", serviceOfArtDemandLst.ExportExcel)
		// 供应商需求明细接收
		RegisterReceiveArtDemandLst(artdemandlst, "/receive", serviceOfArtDemandLst.ChangeArtDemandLstStatus)
		// 供应商需求明细确认
		RegisterConfirmArtDemandLst(artdemandlst, "/confirm", serviceOfArtDemandLst.ChangeArtDemandLstStatus)
		// 供应商需求明细完成
		RegisterAccomplishArtDemandLst(artdemandlst, "/accomplish", serviceOfArtDemandLst.ChangeArtDemandLstStatus)
		//接收文件
		RegisterInsertSyncHronousData(artdemandlst, "/synchronous", serviceOfArtDemandLst.SyncHronousData)

		// Vendor的路由组
		vendor := party.Party("/vendor")
		// Vendor的服务实例
		var serviceOfVendor = svr.NewVendorService()
		// Vendor插入一条
		RegisterInsertOneVendor(vendor, "/insertone", serviceOfVendor.InsertOne)
		// Vendor插入多条
		//RegisterInsertVendor(vendor, "/insert", serviceOfVendor.Insert)
		// Vendor删除一条
		RegisterDeleteOneVendor(vendor, "/deleteone", serviceOfVendor.DeleteOne)
		// Vendor删除多条
		RegisterDeleteVendor(vendor, "/delete", serviceOfVendor.Delete)
		// Vendor查询多条
		RegisterSelectVendor(vendor, "/query", serviceOfVendor.Select)
		// Vendor查询一条
		RegisterSelectOneVendor(vendor, "/get", serviceOfVendor.SelectOne)
		// Vendor修改一条
		RegisterUpdateOneVendor(vendor, "/updateone", serviceOfVendor.UpdateOne)
		// Vendor修改多条
		//RegisterUpdateVendor(vendor, "/update", serviceOfVendor.Update)

		// VendorUserLst的路由组
		vendoruserlst := party.Party("/vendoruserlst")
		// VendorUserLst的服务实例
		var serviceOfVendorUserLst = svr.NewVendorUserLstService()
		// VendorUserLst插入一条
		//RegisterInsertOneVendorUserLst(vendoruserlst, "/insertone", serviceOfVendorUserLst.InsertOne)
		// VendorUserLst插入多条
		RegisterInsertVendorUserLst(vendoruserlst, "/insert", serviceOfVendorUserLst.Insert)
		// VendorUserLst删除一条
		//RegisterDeleteOneVendorUserLst(vendoruserlst, "/deleteone", serviceOfVendorUserLst.DeleteOne)
		// VendorUserLst删除多条
		//RegisterDeleteVendorUserLst(vendoruserlst, "/delete", serviceOfVendorUserLst.Delete)
		// VendorUserLst查询多条
		RegisterSelectVendorUserLst(vendoruserlst, "/query", serviceOfVendorUserLst.Select)
		// VendorUserLst查询一条
		RegisterSelectOneVendorUserLst(vendoruserlst, "/get", serviceOfVendorUserLst.SelectOne)
		// VendorUserLst修改一条
		//RegisterUpdateOneVendorUserLst(vendoruserlst, "/updateone", serviceOfVendorUserLst.UpdateOne)
		// VendorUserLst修改多条
		//RegisterUpdateVendorUserLst(vendoruserlst, "/update", serviceOfVendorUserLst.Update)

		// VendorArtLst的路由组
		vendorartlst := party.Party("/vendorartlst")
		// VendorArtLst的服务实例
		var serviceOfVendorArtLst = svr.NewVendorArtLstService()
		// VendorArtLst插入一条
		//RegisterInsertOneVendorArtLst(vendorartlst, "/insertone", serviceOfVendorArtLst.InsertOne)
		// VendorArtLst插入多条
		RegisterInsertVendorArtLst(vendorartlst, "/insert", serviceOfVendorArtLst.Insert)
		// VendorArtLst删除一条
		//RegisterDeleteOneVendorArtLst(vendorartlst, "/deleteone", serviceOfVendorArtLst.DeleteOne)
		// VendorArtLst删除多条
		//RegisterDeleteVendorArtLst(vendorartlst, "/delete", serviceOfVendorArtLst.Delete)
		// VendorArtLst查询多条
		RegisterSelectVendorArtLst(vendorartlst, "/query", serviceOfVendorArtLst.Select)
		// VendorArtLst查询一条
		RegisterSelectOneVendorArtLst(vendorartlst, "/get", serviceOfVendorArtLst.SelectOne)
		// VendorArtLst修改一条
		//RegisterUpdateOneVendorArtLst(vendorartlst, "/updateone", serviceOfVendorArtLst.UpdateOne)
		// VendorArtLst修改多条
		//RegisterUpdateVendorArtLst(vendorartlst, "/update", serviceOfVendorArtLst.Update)

		// PackOrder的路由组
		packorder := party.Party("/packorder")
		// PackOrder的服务实例
		var serviceOfPackOrder = svr.NewPackOrderService()
		// PackOrder插入一条
		// RegisterInsertOnePackOrder(packorder, "/insertone", serviceOfPackOrder.InsertOne)
		// PackOrder插入多条
		// RegisterInsertPackOrder(packorder, "/insert", serviceOfPackOrder.Insert)
		// PackOrder删除一条
		// RegisterDeleteOnePackOrder(packorder, "/deleteone", serviceOfPackOrder.DeleteOne)
		// PackOrder删除多条
		// RegisterDeletePackOrder(packorder, "/delete", serviceOfPackOrder.Delete)
		// PackOrder查询多条
		RegisterSelectPackOrder(packorder, "/query", serviceOfPackOrder.Select)
		// PackOrder查询多条
		RegisterSelectPackOrderList(packorder, "/querylist", serviceOfPackOrder.SelectList)
		// PackOrder查询一条
		RegisterSelectOnePackOrder(packorder, "/get", serviceOfPackOrder.SelectOne)
		// PackOrder修改一条
		// RegisterUpdateOnePackOrder(packorder, "/updateone", serviceOfPackOrder.UpdateOne)
		// PackOrder修改多条
		// RegisterUpdatePackOrder(packorder, "/update", serviceOfPackOrder.Update)
		// 校验条码生成包装单
		RegisterCheckPackOrder(packorder, "/checkbarcode", serviceOfPackOrder.IsCreatePackOrder)
		//查询可用的包装模板
		RegisterCheckPackOrderTemplate(packorder, "/checktemplates", serviceOfPackOrder.SelectTemplates)
		//根据包装模板创建包装
		RegisterCreatePackOrderByTemplate(packorder, "/createpackorderbytemplate", serviceOfPackOrder.CreatePackOrderByTemplate)
		//检查进入包装规则
		RegisterCheckPackOrderItem(packorder, "/checkpackorderitem", serviceOfPackOrder.CheckPackOrderItem)
		//关闭包装单
		RegisterClosePackOrderItem(packorder, "/closepackorderitem", serviceOfPackOrder.ClosePackOrderItem)

		// PackOrderItemlst的路由组
		packorderitemlst := party.Party("/packorderitemlst")
		// PackOrderItemlst的服务实例
		var serviceOfPackOrderItemlst = svr.NewPackOrderItemlstService()
		// PackOrderItemlst插入一条
		// RegisterInsertOnePackOrderItemlst(packorderitemlst, "/insertone", serviceOfPackOrderItemlst.InsertOne)
		// PackOrderItemlst插入多条
		// RegisterInsertPackOrderItemlst(packorderitemlst, "/insert", serviceOfPackOrderItemlst.Insert)
		// PackOrderItemlst删除一条
		// RegisterDeleteOnePackOrderItemlst(packorderitemlst, "/deleteone", serviceOfPackOrderItemlst.DeleteOne)
		// PackOrderItemlst删除多条
		// RegisterDeletePackOrderItemlst(packorderitemlst, "/delete", serviceOfPackOrderItemlst.Delete)
		// PackOrderItemlst查询多条
		RegisterSelectPackOrderItemlst(packorderitemlst, "/query", serviceOfPackOrderItemlst.Select)
		// PackOrderItemlst查询一条
		RegisterSelectOnePackOrderItemlst(packorderitemlst, "/get", serviceOfPackOrderItemlst.SelectOne)
		// PackOrderItemlst修改一条
		// RegisterUpdateOnePackOrderItemlst(packorderitemlst, "/updateone", serviceOfPackOrderItemlst.UpdateOne)
		// PackOrderItemlst修改多条
		// RegisterUpdatePackOrderItemlst(packorderitemlst, "/update", serviceOfPackOrderItemlst.Update)

		// PackTemplate的路由组
		packtemplate := party.Party("/packtemplate")
		// PackTemplate的服务实例
		var serviceOfPackTemplate = svr.NewPackTemplateService()
		// PackTemplate插入一条
		RegisterInsertOnePackTemplate(packtemplate, "/insertone", serviceOfPackTemplate.InsertOne)
		// PackTemplate插入多条
		// RegisterInsertPackTemplate(packtemplate, "/insert", serviceOfPackTemplate.Insert)
		// PackTemplate删除一条
		RegisterDeleteOnePackTemplate(packtemplate, "/deleteone", serviceOfPackTemplate.DeleteOne)
		// PackTemplate删除多条
		// RegisterDeletePackTemplate(packtemplate, "/delete", serviceOfPackTemplate.Delete)
		// PackTemplate查询多条
		RegisterSelectPackTemplate(packtemplate, "/query", serviceOfPackTemplate.Select)
		// PackTemplate查询一条
		RegisterSelectOnePackTemplate(packtemplate, "/get", serviceOfPackTemplate.SelectOne)
		// PackTemplate修改一条
		RegisterUpdateOnePackTemplate(packtemplate, "/updateone", serviceOfPackTemplate.UpdateOne)
		// PackTemplate修改多条
		// RegisterUpdatePackTemplate(packtemplate, "/update", serviceOfPackTemplate.Update)

		// PackTemplateItemlst的路由组
		packtemplateitemlst := party.Party("/packtemplateitemlst")
		// PackTemplateItemlst的服务实例
		var serviceOfPackTemplateItemlst = svr.NewPackTemplateItemlstService()
		// PackTemplateItemlst插入一条
		// RegisterInsertOnePackTemplateItemlst(packtemplateitemlst, "/insertone", serviceOfPackTemplateItemlst.InsertOne)
		// PackTemplateItemlst插入多条
		// RegisterInsertPackTemplateItemlst(packtemplateitemlst, "/insert", serviceOfPackTemplateItemlst.Insert)
		// PackTemplateItemlst删除一条
		// RegisterDeleteOnePackTemplateItemlst(packtemplateitemlst, "/deleteone", serviceOfPackTemplateItemlst.DeleteOne)
		// PackTemplateItemlst删除多条
		// RegisterDeletePackTemplateItemlst(packtemplateitemlst, "/delete", serviceOfPackTemplateItemlst.Delete)
		// PackTemplateItemlst查询多条
		RegisterSelectPackTemplateItemlst(packtemplateitemlst, "/query", serviceOfPackTemplateItemlst.Select)
		// PackTemplateItemlst查询一条
		RegisterSelectOnePackTemplateItemlst(packtemplateitemlst, "/get", serviceOfPackTemplateItemlst.SelectOne)
		// PackTemplateItemlst修改一条
		// RegisterUpdateOnePackTemplateItemlst(packtemplateitemlst, "/updateone", serviceOfPackTemplateItemlst.UpdateOne)
		// PackTemplateItemlst修改多条
		// RegisterUpdatePackTemplateItemlst(packtemplateitemlst, "/update", serviceOfPackTemplateItemlst.Update)

		// PackTemplatePrintlst的路由组
		packtemplateprintlst := party.Party("/packtemplateprintlst")
		// PackTemplatePrintlst的服务实例
		var serviceOfPackTemplatePrintlst = svr.NewPackTemplatePrintlstService()
		// PackTemplatePrintlst插入一条
		// RegisterInsertOnePackTemplatePrintlst(packtemplateprintlst, "/insertone", serviceOfPackTemplatePrintlst.InsertOne)
		// PackTemplatePrintlst插入多条
		// RegisterInsertPackTemplatePrintlst(packtemplateprintlst, "/insert", serviceOfPackTemplatePrintlst.Insert)
		// PackTemplatePrintlst删除一条
		// RegisterDeleteOnePackTemplatePrintlst(packtemplateprintlst, "/deleteone", serviceOfPackTemplatePrintlst.DeleteOne)
		// PackTemplatePrintlst删除多条
		// RegisterDeletePackTemplatePrintlst(packtemplateprintlst, "/delete", serviceOfPackTemplatePrintlst.Delete)
		// PackTemplatePrintlst查询多条
		RegisterSelectPackTemplatePrintlst(packtemplateprintlst, "/query", serviceOfPackTemplatePrintlst.Select)
		// PackTemplatePrintlst查询一条
		RegisterSelectOnePackTemplatePrintlst(packtemplateprintlst, "/get", serviceOfPackTemplatePrintlst.SelectOne)
		// PackTemplatePrintlst修改一条
		// RegisterUpdateOnePackTemplatePrintlst(packtemplateprintlst, "/updateone", serviceOfPackTemplatePrintlst.UpdateOne)
		// PackTemplatePrintlst修改多条
		// RegisterUpdatePackTemplatePrintlst(packtemplateprintlst, "/update", serviceOfPackTemplatePrintlst.Update)

		// PackType的路由组
		packtype := party.Party("/packtype")
		// PackType的服务实例
		var serviceOfPackType = svr.NewPackTypeService()
		// PackType插入一条
		RegisterInsertOnePackType(packtype, "/insertone", serviceOfPackType.InsertOne)
		// PackType插入多条
		RegisterInsertPackType(packtype, "/insert", serviceOfPackType.Insert)
		// PackType删除一条
		RegisterDeleteOnePackType(packtype, "/deleteone", serviceOfPackType.DeleteOne)
		// PackType删除多条
		// RegisterDeletePackType(packtype, "/delete", serviceOfPackType.Delete)
		// PackType查询多条
		RegisterSelectPackType(packtype, "/query", serviceOfPackType.Select)
		// PackType查询一条
		RegisterSelectOnePackType(packtype, "/get", serviceOfPackType.SelectOne)
		// PackType修改一条
		RegisterUpdateOnePackType(packtype, "/updateone", serviceOfPackType.UpdateOne)
		// PackType修改多条
		// RegisterUpdatePackType(packtype, "/update", serviceOfPackType.Update)

		// ArtDemandHeadCache的路由组
		artdemandheadcache := party.Party("/artdemandheadcache")
		// ArtDemandHeadCache的服务实例
		var serviceOfArtDemandHeadCache = svr.NewArtDemandHeadCacheService()
		// ArtDemandHeadCache插入一条
		// RegisterInsertOneArtDemandHeadCache(artdemandheadcache, "/insertone", serviceOfArtDemandHeadCache.InsertOne)
		// ArtDemandHeadCache插入多条
		// RegisterInsertArtDemandHeadCache(artdemandheadcache, "/insert", serviceOfArtDemandHeadCache.Insert)
		// ArtDemandHeadCache删除一条
		// RegisterDeleteOneArtDemandHeadCache(artdemandheadcache, "/deleteone", serviceOfArtDemandHeadCache.DeleteOne)
		// ArtDemandHeadCache删除多条
		// RegisterDeleteArtDemandHeadCache(artdemandheadcache, "/delete", serviceOfArtDemandHeadCache.Delete)
		// ArtDemandHeadCache查询多条
		RegisterSelectArtDemandHeadCache(artdemandheadcache, "/query", serviceOfArtDemandHeadCache.Select)
		// ArtDemandHeadCache查询一条
		RegisterSelectOneArtDemandHeadCache(artdemandheadcache, "/get", serviceOfArtDemandHeadCache.SelectOne)
		// ArtDemandHeadCache修改一条
		// RegisterUpdateOneArtDemandHeadCache(artdemandheadcache, "/updateone", serviceOfArtDemandHeadCache.UpdateOne)
		// ArtDemandHeadCache修改多条
		// RegisterUpdateArtDemandHeadCache(artdemandheadcache, "/update", serviceOfArtDemandHeadCache.Update)
		RegisterExportArtDemandHeadCacheList(artdemandheadcache, "/exportexcel", serviceOfArtDemandHeadCache.ExportExcel)

		// ArtDemandLstCache的路由组
		artdemandlstcache := party.Party("/artdemandlstcache")
		// ArtDemandLstCache的服务实例
		var serviceOfArtDemandLstCache = svr.NewArtDemandLstCacheService()
		// ArtDemandLstCache插入一条
		// RegisterInsertOneArtDemandLstCache(artdemandlstcache, "/insertone", serviceOfArtDemandLstCache.InsertOne)
		// ArtDemandLstCache插入多条
		// RegisterInsertArtDemandLstCache(artdemandlstcache, "/insert", serviceOfArtDemandLstCache.Insert)
		// ArtDemandLstCache删除一条
		// RegisterDeleteOneArtDemandLstCache(artdemandlstcache, "/deleteone", serviceOfArtDemandLstCache.DeleteOne)
		// ArtDemandLstCache删除多条
		// RegisterDeleteArtDemandLstCache(artdemandlstcache, "/delete", serviceOfArtDemandLstCache.Delete)
		// ArtDemandLstCache查询多条
		RegisterSelectArtDemandLstCache(artdemandlstcache, "/query", serviceOfArtDemandLstCache.Select)
		// ArtDemandLstCache查询一条
		RegisterSelectOneArtDemandLstCache(artdemandlstcache, "/get", serviceOfArtDemandLstCache.SelectOne)
		// ArtDemandLstCache修改一条
		// RegisterUpdateOneArtDemandLstCache(artdemandlstcache, "/updateone", serviceOfArtDemandLstCache.UpdateOne)
		// ArtDemandLstCache修改多条
		// RegisterUpdateArtDemandLstCache(artdemandlstcache, "/update", serviceOfArtDemandLstCache.Update)
		//接收文件
		RegisterInsertSyncHronousDataCache(artdemandlstcache, "/synchronouscache", serviceOfArtDemandLstCache.SyncHronousDataCache)
		// 导出excel
		RegisterExportArtDemandLstCacheList(artdemandlstcache, "/exportexcel", serviceOfArtDemandLstCache.ExportExcel)
	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
